@@ -353,18 +353,21 @@ function get_remote_image_source_files {
     mkdir -p "${metadata_dir}"
 
     image_uri=$(getarg rd.kiwi.install.image=)
+    # make sure the protocol type is tftp for metadata files. There is no need for
+    # complex protocol types on small files and for standard PXE boot operations
+    # only tftp can be guaranteed
     image_md5_uri=$(
-        echo "${image_uri}" | awk '{ gsub("\\.xz",".md5", $1); print $1 }'
+        echo "${image_uri}" | awk '{ gsub("\\.xz",".md5", $1); gsub("dolly:","tftp:", $1); print $1 }'
     )
     image_initrd_uri=$(
-        echo "${image_uri}" | awk '{ gsub("\\.xz",".initrd", $1); print $1 }'
+        echo "${image_uri}" | awk '{ gsub("\\.xz",".initrd", $1); gsub("dolly:","tftp:", $1); print $1 }'
     )
     image_kernel_uri=$(
-        echo "${image_uri}" | awk '{ gsub("\\.xz",".kernel", $1); print $1 }'
+        echo "${image_uri}" | awk '{ gsub("\\.xz",".kernel", $1); gsub("dolly:","tftp:", $1); print $1 }'
     )
     image_config_uri=$(
         echo "${image_uri}" | \
-        awk '{ gsub("\\.xz",".config.bootoptions", $1); print $1 }'
+        awk '{ gsub("\\.xz",".config.bootoptions", $1); gsub("dolly:","tftp:", $1); print $1 }'
     )
 
     # if we can not access image_md5_uri, maybe network setup
