@@ -85,6 +85,7 @@ class LiveImageBuilder:
         self.system_setup = SystemSetup(
             xml_state=xml_state, root_dir=self.root_dir
         )
+        self.bundle_format = xml_state.get_build_type_bundle_format()
         self.isoname = ''.join(
             [
                 target_dir, '/',
@@ -113,7 +114,7 @@ class LiveImageBuilder:
         """
         # media dir to store CD contents
         self.media_dir = Temporary(
-            prefix='live-media.', dir=self.target_dir
+            prefix='live-media.', path=self.target_dir
         ).new_dir()
 
         # unpack cdroot user files to media dir
@@ -248,7 +249,7 @@ class LiveImageBuilder:
 
         log.info('--> Creating squashfs container for root image')
         self.live_container_dir = Temporary(
-            prefix='live-container.', dir=self.target_dir
+            prefix='live-container.', path=self.target_dir
         ).new_dir()
         Path.create(self.live_container_dir.name + '/LiveOS')
         shutil.copy(
@@ -288,6 +289,8 @@ class LiveImageBuilder:
             self.runtime_config.get_max_size_constraint(),
             self.isoname
         )
+        if self.bundle_format:
+            self.result.add_bundle_format(self.bundle_format)
         self.result.add(
             key='live_image',
             filename=self.isoname,
