@@ -808,3 +808,30 @@ class KiwiIncludFileNotFoundError(KiwiError):
     Exception raised if the file reference in an <include>
     statement could not be found
     """
+
+
+class KiwiUmountBusyError(KiwiError):
+    """
+    Exception raised if the attempt to umount a resource has failed
+    """
+
+
+class KiwiCustomPartitionConflictError(KiwiError):
+    """
+    Exception raised if the entry in a custom partition setup
+    conflicts with an existing partition table layout setting
+    """
+
+
+class KiwiVolumeTooSmallError(KiwiError):
+    """
+    Exception raised if the specified volume size is smaller
+    than the required bytes to store the data
+    """
+
+
+class KiwiPartitionTooSmallError(KiwiError):
+    """
+    Exception raised if the specified partition size is smaller
+    than the required bytes to store the data
+    """
