@@ -1,8 +1,6 @@
 import logging
 from pytest import fixture
-from mock import (
-    patch, call
-)
+from mock import patch
 import mock
 
 from kiwi.filesystem.isofs import FileSystemIsoFs
@@ -26,56 +24,41 @@ class TestFileSystemIsoFs:
 
     @patch('kiwi.filesystem.isofs.IsoTools')
     @patch('kiwi.filesystem.isofs.Iso')
-    def test_create_on_file(self, mock_iso, mock_cdrtools):
+    def test_create_on_file(self, mock_iso, mock_IsoTools):
         iso_tool = mock.Mock()
         iso_tool.has_iso_hybrid_capability = mock.Mock(
-            return_value=False
+            return_value=True
         )
         iso_tool.get_tool_name = mock.Mock(
-            return_value='/usr/bin/mkisofs'
+            return_value='/usr/bin/xorriso'
         )
+        mock_IsoTools.new.return_value = iso_tool
         iso = mock.Mock()
         iso.header_end_name = 'header_end'
-        mock_cdrtools.new.return_value = iso_tool
         mock_iso.return_value = iso
         self.isofs.create_on_file('myimage', None)
 
         iso.setup_isolinux_boot_path.assert_called_once_with()
-        iso.create_header_end_marker.assert_called_once_with()
 
         iso_tool.init_iso_creation_parameters.assert_called_once_with({})
+
         iso_tool.add_efi_loader_parameters.assert_called_once_with()
 
-        iso.create_header_end_block.assert_called_once_with('myimage')
-
-        assert iso_tool.create_iso.call_args_list == [
-            call('myimage'), call('myimage', hidden_files=['header_end'])
-        ]
-
-        iso.relocate_boot_catalog.assert_called_once_with(
-            'myimage'
-        )
-        iso.fix_boot_catalog.assert_called_once_with(
-            'myimage'
-        )
-        iso.create_hybrid.assert_called_once_with(
-            iso.create_header_end_block.return_value,
-            '0xffffffff', 'myimage'
-        )
+        iso_tool.create_iso.assert_called_once_with('myimage')
 
     @patch('kiwi.filesystem.isofs.IsoTools')
     @patch('kiwi.filesystem.isofs.Iso')
-    def test_create_on_file_EFI_enabled(self, mock_iso, mock_cdrtools):
+    def test_create_on_file_EFI_enabled(self, mock_iso, mock_IsoTools):
         iso_tool = mock.Mock()
         iso_tool.has_iso_hybrid_capability = mock.Mock(
-            return_value=False
+            return_value=True
         )
         iso_tool.get_tool_name = mock.Mock(
-            return_value='/usr/bin/mkisofs'
+            return_value='/usr/bin/xorriso'
         )
+        mock_IsoTools.new.return_value = iso_tool
         iso = mock.Mock()
         iso.header_end_name = 'header_end'
-        mock_cdrtools.new.return_value = iso_tool
         mock_iso.return_value = iso
         self.isofs.custom_args['meta_data']['efi_mode'] = 'uefi'
         with self._caplog.at_level(logging.WARNING):
